pub struct ReviewFinding {
pub code: String,
pub message: String,
pub target: ReviewTarget,
}Fields
code: Stringmessage: Stringtarget: ReviewTargetTrait Implementations
Sourceimpl Clone for ReviewFinding
impl Clone for ReviewFinding
Sourcefn clone(&self) -> ReviewFinding
fn clone(&self) -> ReviewFinding
Returns a duplicate of the value. Read more
1.0.0 · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for ReviewFinding
impl Debug for ReviewFinding
Sourceimpl<'de> Deserialize<'de> for ReviewFinding
impl<'de> Deserialize<'de> for ReviewFinding
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
Sourceimpl JsonSchema for ReviewFinding
impl JsonSchema for ReviewFinding
Sourcefn schema_id() -> Cow<'static, str>
fn schema_id() -> Cow<'static, str>
Returns a string that uniquely identifies the schema produced by this type. Read more
Sourcefn json_schema(generator: &mut SchemaGenerator) -> Schema
fn json_schema(generator: &mut SchemaGenerator) -> Schema
Generates a JSON Schema for this type. Read more
Sourcefn inline_schema() -> bool
fn inline_schema() -> bool
Whether JSON Schemas generated for this type should be included directly in parent schemas,
rather than being re-used where possible using the
$ref keyword. Read moreSourceimpl PartialEq for ReviewFinding
impl PartialEq for ReviewFinding
Sourceimpl Serialize for ReviewFinding
impl Serialize for ReviewFinding
impl Eq for ReviewFinding
impl StructuralPartialEq for ReviewFinding