pub struct ReviewTarget {
pub kind: ReviewTargetKind,
pub reference: String,
}Fields
kind: ReviewTargetKindreference: StringTrait Implementations
Sourceimpl Clone for ReviewTarget
impl Clone for ReviewTarget
Sourcefn clone(&self) -> ReviewTarget
fn clone(&self) -> ReviewTarget
Returns a duplicate of the value. Read more
1.0.0 · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for ReviewTarget
impl Debug for ReviewTarget
Sourceimpl<'de> Deserialize<'de> for ReviewTarget
impl<'de> Deserialize<'de> for ReviewTarget
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
Sourceimpl JsonSchema for ReviewTarget
impl JsonSchema for ReviewTarget
Sourcefn schema_id() -> Cow<'static, str>
fn schema_id() -> Cow<'static, str>
Returns a string that uniquely identifies the schema produced by this type. Read more
Sourcefn json_schema(generator: &mut SchemaGenerator) -> Schema
fn json_schema(generator: &mut SchemaGenerator) -> Schema
Generates a JSON Schema for this type. Read more
Sourcefn inline_schema() -> bool
fn inline_schema() -> bool
Whether JSON Schemas generated for this type should be included directly in parent schemas,
rather than being re-used where possible using the
$ref keyword. Read moreSourceimpl PartialEq for ReviewTarget
impl PartialEq for ReviewTarget
Sourceimpl Serialize for ReviewTarget
impl Serialize for ReviewTarget
impl Eq for ReviewTarget
impl StructuralPartialEq for ReviewTarget